@@ -48,7 +48,7 @@ def test_load_data():
     assert len(ds) == 2
     assert ds.path.samefile(pathlib.Path(tf))
     assert np.isnan(ds.get_time(1))
-    assert "SeriesHdf5Qpimage" in ds.__repr__()
+    assert "SeriesPhaseQpimageHDF5" in ds.__repr__()
     qpd = ds.get_qpimage(1)
     assert qpd["identifier"] != qpi1["identifier"]
     assert qpd == qpi1
@@ -139,7 +139,7 @@ def test_subjoined_load_data():
     assert len(ds) == 2
     assert ds.path.samefile(pathlib.Path(tf))
     assert np.isnan(ds.get_time(1))
-    assert "SeriesHdf5QpimageSubjoined" in ds.__repr__()
+    assert "SeriesPhaseQpimageSubjoinedHDF5" in ds.__repr__()
     qpd = ds.get_qpimage(1)
     assert qpd["identifier"] != qpi1["identifier"]
     assert qpd == qpi1
