@@ -13,13 +13,13 @@ def test_basic():
     assert ds.storage_type == "raw-oah"
     assert not ds.is_series
     assert ds.path == path.resolve()
-    assert "SingleTifHolo" in ds.__repr__()
+    assert "SingleRawOAHTif" in ds.__repr__()
 
 
 def test_identifier():
     path = datapath / "single_holo.tif"
-    ds = qpformat.load_data(path, holo_kw={"sideband": 1})
-    assert ds.identifier == "b65c8"
+    ds = qpformat.load_data(path, qpretrieve_kw={"invert_phase": False})
+    assert ds.identifier == "9e409"
 
 
 def test_load_data():
